/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.indexing.overlord.supervisor.autoscaler;

public interface SupervisorTaskAutoScaler
{
  void start();
  void stop();
  void reset();

  /**
   * Computes the optimal task count during task rollover, allowing a non-disruptive scale-down.
   * Must be called by the supervisor when tasks are ending their duration.
   *
   * @return optimal task count for scale-down, or -1 if no change needed
   */
  default int computeTaskCountForRollover()
  {
    return -1;
  }
}
